import { execSync } from "child_process";
import { copyFolderSync } from "../utils/utils.js";
import { fileURLToPath } from "url";
import path from "path";
import fs from "fs";

export const setupGulp = async (dir: string): Promise<void> => {
  console.log(`Setup Gulp\n`);

  const __filename = fileURLToPath(import.meta.url);
  const __dirname = path.dirname(__filename);
  const templateDir = path.join(__dirname, "..", "..", "template", "gulp");
  copyFolderSync(templateDir, dir);

  const filePath = path.join(dir, "README.md");
  const fileContent = fs.readFileSync(filePath, "utf-8");
  const updatedContent = fileContent.replaceAll("{{NODE_VERSION}}", process.env.NODE_VERSION || "");
  fs.writeFileSync(filePath, updatedContent, "utf-8");

  try {
    execSync(`cd ${dir} && npm init -y`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install --save-dev gulp`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install --global gulp-cli`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-sass --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install sass --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-concat --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-uglify --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-clean-css --save-dev`, { stdio: "inherit" });
    execSync(`cd ${dir} && npm install gulp-sourcemaps --save-dev`, { stdio: "inherit" });
  } catch (error) {
    console.error(error);
  }
};
