const gulp = require("gulp");
const sass = require("gulp-sass")(require("sass"));
const concat = require("gulp-concat");
const uglify = require("gulp-uglify");
const cleanCSS = require("gulp-clean-css");
const sourcemaps = require("gulp-sourcemaps");

const paths = {
  scss: ["scss/**/*.scss", "./components/**/*.scss", "./modules/**/*.scss"],
  js: ["utils/**/*.js", "./components/**/*.js", "./modules/**/*.js"],
};

const isProduction = process.env.NODE_ENV === "production";

gulp.task("styles", function () {
  const pipeline = gulp.src(paths.scss);

  if (!isProduction) {
    pipeline.pipe(sourcemaps.init());
  }

  pipeline.pipe(sass().on("error", sass.logError)).pipe(cleanCSS()).pipe(concat("main.css"));

  if (!isProduction) {
    pipeline.pipe(sourcemaps.write("."));
  }

  return pipeline.pipe(gulp.dest("../../wwwroot/css"));
});

gulp.task("scripts", function () {
  const pipeline = gulp.src(paths.js);

  if (!isProduction) {
    pipeline.pipe(sourcemaps.init());
  }

  pipeline.pipe(concat("bundle.js")).pipe(uglify());

  if (!isProduction) {
    pipeline.pipe(sourcemaps.write("."));
  }

  return pipeline.pipe(gulp.dest("../../wwwroot/scripts"));
});

gulp.task("watch", function () {
  gulp.watch(paths.scss, gulp.series("styles"));
  gulp.watch(paths.js, gulp.series("scripts"));
});

gulp.task("default", gulp.series("styles", "scripts", "watch"));
gulp.task("production", gulp.series("styles", "scripts"));
gulp.task("dev", gulp.series("styles", "scripts"));
